
#include <fstream>
#include <vector>
#include <iostream>
#include <cmath>

const double eps = 1E-10;

template<typename T> inline T sqr(const T& x)
{
  return x*x;
}

int main (int argc, char** argv)
{
  std::vector<double> x, y, z;
  int n;
  std::fstream input("input.txt", std::ios_base::in);
  std::fstream output("output.txt", std::ios_base::out);

  input >> n;
  x.resize(n); y.resize(n); z.resize(n);
  for (int i = 0; i < n; ++i) input >> x[i] >> y[i] >> z[i];

  for (int i = 0; i < n; ++i)
  { 
    bool canwin = false;
    bool allbad = false;


    std::vector<double> a, b, c;

    a.push_back(1); b.push_back(0); c.push_back(0);
    a.push_back(0); b.push_back(1); c.push_back(0);
    for (int j = 0; j < n; ++j)
      if (i != j)
      {
        double ta = 1 / x[j] - 1 / x[i]; 
        double tb = 1 / y[j] - 1 / y[i];
        double tc = 1 / z[i] - 1 / z[j];
        double tn = std::sqrt(ta*ta + tb*tb); 
        if (tn > eps)
        {
          a.push_back(ta / tn); b.push_back(tb / tn); c.push_back(tc / tn);
        }
        else
          allbad |= tc >= -eps;
      }

    int m = a.size();
    for (int j = 0; j < m; ++j)
    {
      double mnx, mny, plx, ply;
      int mni = -1; 
      int pli = -1;
      bool smallbad = false;
      for (int k = 0; k < m; ++k)
      {
        double dt = a[j] * b[k] - b[j] * a[k];
        if (std::abs(dt) < eps)
        {

          if (sqr(a[j] + a[k]) + sqr(b[j] + b[k]) < eps)
            smallbad |= c[j] + c[k] >= -eps;
          else
            smallbad |= c[k] > c[j];

        }
        else
        {
          double tx = (c[j] * b[k] - b[j] * c[k]) / dt;
          double ty = (a[j] * c[k] - c[j] * a[k]) / dt;
          
          if (dt > 0)
          {
            if (pli == -1 || tx*a[pli] + ty*b[pli] > c[pli]) { pli = k; plx = tx; ply = ty; }
          }
          else
          {
            if (mni == -1 || tx*a[mni] + ty*b[mni] > c[mni]) { mni = k; mnx = tx; mny = ty; }
          }
        }
      }
      canwin |= (!allbad && !smallbad && ((pli == -1) || (mni == -1) || (mnx * a[pli] + mny * b[pli] - c[pli] > eps )));
    }
    output << (canwin ? "Yes" : "No") << std::endl;
  }

  return 0;
}
